Discover Packages
github.com/3th-JustFunTeam/Tiktok-Backend
config
package
Version:
v0.0.0-...-c335ce4
Opens a new window with list of versions in this module.
Published: Jun 13, 2022
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Config struct {
MySQL MySQL `yaml:"mysql"`
Redis Redis `yaml:"redis"`
}
type MySQL struct {
Host string `yaml:"host"`
Port int32 `yaml:"port"`
User string `yaml:"user"`
Password string `yaml:"password"`
Database string `yaml:"database"`
}
type Redis struct {
Host string `yaml:"host"`
Port int32 `yaml:"port"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.